#!/usr/bin/python
##########
#
# Name: measure_temp_loop.py
# Description:measure tempature from DHT22 senors in GPIO11
# Version 1.1
# Date: March 31, 2018
#
#########

import sys			#provides access to some variables used or maintained by the interpreter
import os			#provides a portable way of using operating system dependent functionality.
import datetime			#provides classes for manipulating dates and times
import time			#provides various time-related functions
import RPi.GPIO as GPIO		#provides interface to input/output pins of the Pi
import Adafruit_DHT		#provides the ability to read the DHT series of sensors from a Raspberry Pi

#setup
GPIO.setmode(GPIO.BOARD)	#set option to reference physical pins


try:

	humidity, temperature = Adafruit_DHT.read_retry(Adafruit_DHT.AM2302,14)	#GPIO 14 found on pin 8

	time.sleep(3)

	if humidity is not None and temperature is not None:
		#print('Temp = {0:0.1f}'.format(temperature))
		temp_reading = ('{0:0.1f}'.format(temperature))
		#with open("/home/pi/temperature.txt","w") as f:
		with open("/dev/shm/mjpeg/user_annotate.txt","w") as f:
			f.write(temp_reading)
	else:
		#Sometimes you might see an error that the sensor can't be read and to try again, even if you have your connections setup correctly. This is a limitation of reading DHT sensors from Linux--there's no guarantee the program will be given enough priority and time by the Linux kernel to reliably read the sensor. If this occurs, run the program again (or call the read function again in your code) to try to get a new reading.
    		print('Failed to get reading. Try again!')
		temperature = 0	# set a value so there is variable to support the code.


except KeyboardInterrupt: #if ctrl+c pressed exit cleanly
	GPIO.cleanup()
except: # this catches ALL other exceptions including errors.
	GPIO.cleanup()
finally: #cleanup GPIO on normal exit
	GPIO.cleanup()

